@@ -9,7 +9,7 @@
 ;; Package-Requires: ((emacs "28.1") (compat "30.1.0.0"))
 ;; Homepage: https://github.com/DevelopmentCool2449/colorful-mode
 ;; Keywords: faces, tools, matching, convenience
-;; Version: 1.2.4
+;; Version: 1.2.5
 
 ;; This file is part of GNU Emacs.
 
@@ -427,6 +427,7 @@ BEG is the position to check for the overlay."
           (if (use-region-p)
               (list (region-beginning) (region-end)))))
 
+  ;; 1# Case: replace all the colors in an active region.
   (if (and beg end)
       (let* ((choices '(("Hexadecimal color format" . hex)
                         ("Color name" . name)))
@@ -434,7 +435,8 @@ BEG is the position to check for the overlay."
              (choice (alist-get
                       (completing-read "Change colors in region: " choices nil t nil nil)
                       choices nil nil 'equal))
-             (ignored-colors 0) ; Define counter
+             ;; Define counters
+             (ignored-colors 0)
              (changed-colors 0))
 
         (dolist (ov (overlays-in beg end))
@@ -451,13 +453,14 @@ BEG is the position to check for the overlay."
                   (setq changed-colors (1+ changed-colors)))
               (setq ignored-colors (1+ ignored-colors)))))
 
-        (if (and (= changed-colors 0)
-                 (= ignored-colors 0))
+        (if (and (zerop changed-colors)
+                 (zerop ignored-colors))
             (message "No color found in region.")
           (message (concat (propertize "Changed colors: %d" 'face 'success) " / "
                            (propertize "Ignored colors: %d" 'face 'error))
                    changed-colors ignored-colors)))
 
+    ;; 2# Case: replace only the color at point
     (if-let* ((colorful-ov (colorful--find-overlay)) ; Find colorful overlay tag at point/cursor.
               ;; Start prompt for color change and get new color.
               (result (colorful--prompt-converter colorful-ov "Change '%s' to: "))
@@ -484,7 +487,7 @@ BEG is the position to check for the overlay."
       ;; Copy color and notify to user it's done
       (progn (kill-new color)
              (message "`%s' copied." color))
-    ;; Otherwise throw error.
+    ;; Otherwise throw an error.
     (user-error "No color found")))
 
 (defun colorful-change-or-copy-color ()
@@ -652,9 +655,9 @@ BEG and END are color match positions."
          (setq color
                (if (string-prefix-p "{R" color)  ; Check if it's RGB (shorted as "{R")
                    (format "#%02x%02x%02x"
-                           (/ (string-to-number match-1) 250.0) ; r
-                           (/ (string-to-number match-2) 250.0) ; g
-                           (/ (string-to-number match-3) 250.0)) ; b
+                           (string-to-number match-1) ; r
+                           (string-to-number match-2) ; g
+                           (string-to-number match-3)) ; b
                  (color-rgb-to-hex
                   (string-to-number match-1) ; r
                   (string-to-number match-2) ; g
@@ -718,13 +721,18 @@ BEG and END are color match positions."
                        :foreground (readable-foreground-color color)
                        :background color
                        :inherit 'colorful-base)))
+              ;; Make the function for the mouse clicks
               (map (when colorful-allow-mouse-clicks
                      `(keymap
-                       ,(cons
-                         'mouse-1
-                         (if buffer-read-only
-                             'colorful-convert-and-copy-color
-                           'colorful-change-or-copy-color))))))
+                       (mouse-1
+                        . ,(lambda ()
+                             (interactive)
+                             (save-excursion
+                               (goto-char beg)
+                               (call-interactively
+                                (if buffer-read-only
+                                    #'colorful-convert-and-copy-color
+                                  #'colorful-change-or-copy-color)))))))))
           (colorful--colorize-match color beg end kind face map))))))
 
 ;;; Fontify functions
@@ -848,7 +856,7 @@ This is intended to be used with `colorful-extra-color-keyword-functions'."
                (opt (or "/" ",") (zero-or-more " ")
                     (or (seq (zero-or-one digit)
                              (opt ".")
-                             digit)
+                             (one-or-more digit))
                         digit)
                     (opt (or "%" (zero-or-more " "))))
                ")"))
@@ -878,7 +886,7 @@ This is intended to be used with `colorful-extra-color-keyword-functions'."
                (opt (or "/" ",") (zero-or-more " ")
                     (group (or (seq (zero-or-one digit)
                                     (opt ".")
-                                    digit)
+                                    (one-or-more digit))
                                digit)
                            (opt (or "%" (zero-or-more " ")))))
                ")"))
@@ -901,7 +909,7 @@ This is intended to be used with `colorful-extra-color-keyword-functions'."
                (opt (or "/" ",") (zero-or-more " ")
                     (group (or (seq (zero-or-one digit)
                                     (opt ".")
-                                    digit)
+                                    (one-or-more digit))
                                digit)
                            (opt (or "%" (zero-or-more " ")))))
                ")"))
@@ -917,14 +925,14 @@ This is intended to be used with `colorful-extra-color-keyword-functions'."
    `(,(rx (seq "hsl" (opt "a") "(" (zero-or-more " ")
                (group (repeat 1 3 digit) (opt (or "deg" "grad" "rad")))
                (zero-or-more " ") (opt "," (zero-or-more " "))
-               (group (repeat 1 3 digit) (opt "%"))
+               (group (repeat 1 3 digit) (opt "." (1+ digit)) (opt "%"))
                (zero-or-more " ") (opt "," (zero-or-more " "))
-               (group (repeat 1 3 digit) (opt "%"))
+               (group (repeat 1 3 digit) (opt "." (1+ digit)) (opt "%"))
                (zero-or-more " ")
                (opt (or "/" ",") (zero-or-more " ")
                     (or (seq (zero-or-one digit)
                              (opt ".")
-                             digit)
+                             (one-or-more digit))
                         digit)
                     (opt (or "%" (zero-or-more " "))))
                ")"))
@@ -967,10 +975,8 @@ This is intended to be used with `colorful-extra-color-keyword-functions'."
      ((and (listp fn)
            ;; For emacs < 28.1 compatibility (see: github#19)
            (seq-some #'derived-mode-p (ensure-list (car fn))))
-      (if (listp (cdr fn))
-          (dolist (fn-list (cdr fn))
-            (funcall fn-list))
-        (funcall (cdr fn))))
+      (dolist (fn-list (ensure-list (cdr fn)))
+        (funcall fn-list)))
 
      ;; If current major mode is not derived from any mode defined in
      ;; `colorful-extra-color-keyword-functions', use the
